==> sal-organization-1.10.10-20161012.073240-6-sources.jar: com/baijia/tianxiao/sal/organization/org/dto/OrgBaseInfoModel.java <==

 /**
 * Baijiahulian.com Inc.
 * Copyright (c) 2014-2015 All Rights Reserved.
 */
    
package com.baijia.tianxiao.sal.organization.org.dto;

import net.sf.json.JSONObject;
import com.baijia.tianxiao.dto.BaseDto;


/**
 * 机构模板中机构基本信息
 * @title OrgInfoModel
 * @desc TODO 
 * @author zhangbing
 * @date 2015年12月4日
 * @version 1.0
 */
public class OrgBaseInfoModel extends BaseDto {

    private static final long serialVersionUID = 3216574788907760850L;
    //机构简称
    private String shortName;
    //机构ID
    private Integer id;
    //机构number
    private Integer number;
    //机构校区地址
    private String address;
    //机构个性化域名
    private String domain;
    //特色标签
    private String[] tags;
    //一句话简介
    private String brief;
    //机构logo
    private String logo;
    //400分机号
    private String extension;
    //可报名的机构班课+3810课程之和
    private Integer courseCount;
    
    private JSONObject links;

    private Integer templateId;

    
    /**
     * @return the shortName
     */
    
    public String getShortName() {
    
        return shortName;
    }
    /**
     * @param shortName the shortName to set
     */
    
    public void setShortName(String shortName) {
    
        this.shortName = shortName;
    }
    /**
     * @return the id
     */
    
    public Integer getId() {
    
        return id;
    }
    /**
     * @param id the id to set
     */
    
    public void setId(Integer id) {
    
        this.id = id;
    }
    /**
     * @return the number
     */
    
    public Integer getNumber() {
    
        return number;
    }
    /**
     * @param number the number to set
     */
    
    public void setNumber(Integer number) {
    
        this.number = number;
    }
    /**
     * @return the address
     */
    
    public String getAddress() {
    
        return address;
    }
    /**
     * @param address the address to set
     */
    
    public void setAddress(String address) {
    
        this.address = address;
    }
    /**
     * @return the domain
     */
    
    public String getDomain() {
    
        return domain;
    }
    /**
     * @param domain the domain to set
     */
    
    public void setDomain(String domain) {
    
        this.domain = domain;
    }
    /**
     * @return the tags
     */
    
    public String[] getTags() {
    
        return tags;
    }
    /**
     * @param tags the tags to set
     */
    
    public void setTags(String[] tags) {
    
        this.tags = tags;
    }
    /**
     * @return the brief
     */
    
    public String getBrief() {
    
        return brief;
    }
    /**
     * @param brief the brief to set
     */
    
    public void setBrief(String brief) {
    
        this.brief = brief;
    }
    /**
     * @return the logo
     */
    
    public String getLogo() {
    
        return logo;
    }
    /**
     * @param logo the logo to set
     */
    
    public void setLogo(String logo) {
    
        this.logo = logo;
    }
    /**
     * @return the extension
     */
    
    public String getExtension() {
    
        return extension;
    }
    /**
     * @param extension the extension to set
     */
    
    public void setExtension(String extension) {
    
        this.extension = extension;
    }
    /**
     * @return the courseCount
     */
    
    public Integer getCourseCount() {
    
        return courseCount;
    }
    /**
     * @param courseCount the courseCount to set
     */
    
    public void setCourseCount(Integer courseCount) {
    
        this.courseCount = courseCount;
    }
    /**
     * @return the links
     */
    
    public JSONObject getLinks() {
    
        return links;
    }
    /**
     * @param links the links to set
     */
    
    public void setLinks(JSONObject links) {
    
        this.links = links;
    }

    public Integer getTemplateId() {
        return templateId;
    }

    public void setTemplateId(Integer templateId) {
        this.templateId = templateId;
    }
}

==> sal-organization-2.32.0-20170902.065446-216-sources.jar: com/baijia/tianxiao/sal/organization/org/dto/OrgBaseInfoModel.java <==

/**
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 */

package com.baijia.tianxiao.sal.organization.org.dto;

import net.sf.json.JSONArray;
import net.sf.json.JSONObject;
import com.baijia.tianxiao.dto.BaseDto;

/**
 * 机构模板中机构基本信息
 * 
 * @title OrgInfoModel
 * @desc TODO
 * @author zhangbing
 * @date 2015年12月4日
 * @version 1.0
 */
public class OrgBaseInfoModel extends BaseDto {

    private static final long serialVersionUID = 3216574788907760850L;
    // 机构简称
    private String shortName;
    // 机构ID
    private Integer id;
    // 机构number
    private Integer number;
    // 机构校区地址
    private String address;
    // 机构个性化域名
    private String domain;
    // 特色标签
    private String[] tags;
    // 一句话简介
    private String brief;
    // 机构logo
    private String logo;
    // 400分机号
    private String extension;
    // 可报名的机构班课+3810课程之和
    private Integer courseCount;

    private JSONArray branches;

    private JSONObject links;

    private Integer templateId;

    /**
     * @return the shortName
     */

    public String getShortName() {

        return shortName;
    }

    /**
     * @param shortName the shortName to set
     */

    public void setShortName(String shortName) {

        this.shortName = shortName;
    }

    /**
     * @return the id
     */

    public Integer getId() {

        return id;
    }

    /**
     * @param id the id to set
     */

    public void setId(Integer id) {

        this.id = id;
    }

    /**
     * @return the number
     */

    public Integer getNumber() {

        return number;
    }

    /**
     * @param number the number to set
     */

    public void setNumber(Integer number) {

        this.number = number;
    }

    /**
     * @return the address
     */

    public String getAddress() {

        return address;
    }

    /**
     * @param address the address to set
     */

    public void setAddress(String address) {

        this.address = address;
    }

    /**
     * @return the domain
     */

    public String getDomain() {

        return domain;
    }

    /**
     * @param domain the domain to set
     */

    public void setDomain(String domain) {

        this.domain = domain;
    }

    /**
     * @return the tags
     */

    public String[] getTags() {

        return tags;
    }

    /**
     * @param tags the tags to set
     */

    public void setTags(String[] tags) {

        this.tags = tags;
    }

    /**
     * @return the brief
     */

    public String getBrief() {

        return brief;
    }

    /**
     * @param brief the brief to set
     */

    public void setBrief(String brief) {

        this.brief = brief;
    }

    /**
     * @return the logo
     */

    public String getLogo() {

        return logo;
    }

    /**
     * @param logo the logo to set
     */

    public void setLogo(String logo) {

        this.logo = logo;
    }

    /**
     * @return the extension
     */

    public String getExtension() {

        return extension;
    }

    /**
     * @param extension the extension to set
     */

    public void setExtension(String extension) {

        this.extension = extension;
    }

    /**
     * @return the courseCount
     */

    public Integer getCourseCount() {

        return courseCount;
    }

    /**
     * @param courseCount the courseCount to set
     */

    public void setCourseCount(Integer courseCount) {

        this.courseCount = courseCount;
    }

    /**
     * @return the links
     */

    public JSONObject getLinks() {

        return links;
    }

    /**
     * @param links the links to set
     */

    public void setLinks(JSONObject links) {

        this.links = links;
    }

    public Integer getTemplateId() {
        return templateId;
    }

    public void setTemplateId(Integer templateId) {
        this.templateId = templateId;
    }

    /**
     * @return the branches
     */

    public JSONArray getBranches() {

        return branches;
    }

    /**
     * @param branches the branches to set
     */

    public void setBranches(JSONArray branches) {

        this.branches = branches;
    }

}
